Enum Key

pub enum Key<C = SmolStr> {
    Named(Named),
    Character(C),
    Unidentified,
}
A key on the keyboard.

This is mostly the Key type found in winit.

Variants



Named(Named)

A key with an established name.



Character(C)

A key string that corresponds to the character typed by the user, taking into account the user’s current locale setting, and any system-level keyboard mapping overrides that are in effect.



Unidentified

An unidentified key.

Implementations



impl Key

pub fn as_ref(&self) -> Key<&str>

Convert Key::Character(SmolStr) to Key::Character(&str) so you can more easily match on Key. All other variants remain unchanged.

pub fn to_latin(&self, physical_key: Physical) -> Option<char>

Tries to convert this logical Key into its latin character, using the Physical key provided for translation if it isn’t already in latin.

Returns None if no latin variant could be found.

use iced_core::keyboard::key::{Key, Named, Physical, Code};

// Latin c
assert_eq!(
    Key::Character("c".into()).to_latin(Physical::Code(Code::KeyC)),
    Some('c'),
);

// Cyrillic с
assert_eq!(
    Key::Character("с".into()).to_latin(Physical::Code(Code::KeyC)),
    Some('c'),
);

// Arrow Left
assert_eq!(
    Key::Named(Named::ArrowLeft).to_latin(Physical::Code(Code::ArrowLeft)),
    None,
);